==> keepassx_0.3.3.orig.tar.gz: keepassx-0.3.3/src/lib/AutoTypeTreeWidget.h <==
/***************************************************************************
 *   Copyright (C) 2005-2008 by Tarek Saidi                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; version 2 of the License.               *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


class AutoTypeTreeWidget : public QTreeWidget {
Q_OBJECT
public:
	AutoTypeTreeWidget(QWidget* parent):QTreeWidget(parent){}
signals:
	void returnPressed(QTreeWidgetItem*);
private:
	void mouseMoveEvent(QMouseEvent*);
	void keyPressEvent(QKeyEvent*);
};

==> keepassx_0.4.3+dfsg.orig.tar.gz: keepassx-0.4.3/src/lib/AutoTypeTreeWidget.h <==
/***************************************************************************
 *   Copyright (C) 2005-2008 by Tarek Saidi                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; version 2 of the License.               *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


class AutoTypeTreeWidget : public QTreeWidget {
	Q_OBJECT
	
	public:
		AutoTypeTreeWidget(QWidget* parent):QTreeWidget(parent){};
	
	signals:
		void returnPressed(QTreeWidgetItem*);
	
	private:
		void mouseMoveEvent(QMouseEvent*);
		void keyPressEvent(QKeyEvent*);
};
